@@ -6,16 +6,13 @@ Rubric - a notes and bookmarks manager with tagging
 
 =head1 VERSION
 
-version 0.03_03
+version 0.07_01
 
- $Id: Rubric.pm,v 1.12 2005/01/20 15:09:06 rjbs Exp $
+ $Id: Rubric.pm,v 1.17 2005/03/17 03:32:39 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.03_04';
-
-warn "Rubric.pm isn't meant to be used.";
-exit 1;
+our $VERSION = '0.07_01';
 
 =head1 DESCRIPTION
 
