@@ -6,7 +6,7 @@ Rubric::Entry - a single entry made by a user
 
 =head1 VERSION
 
- $Id: Entry.pm,v 1.19 2005/01/16 03:52:46 rjbs Exp $
+ $Id: Entry.pm,v 1.21 2005/01/23 20:00:24 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -47,6 +47,12 @@ The link attribute returns a Rubric::Link.
 
 __PACKAGE__->has_a(link => 'Rubric::Link');
 
+=head2 uri
+
+The uri attribuet returns the URI of the entry's link.
+
+=cut
+
 sub uri { my ($self) = @_; return unless $self->link; $self->link->uri; }
 
 =head2 user
@@ -66,7 +72,7 @@ represent them.
 =cut
 
 __PACKAGE__->has_many(entrytags => 'Rubric::EntryTag' );
-__PACKAGE__->has_many(tags => [ 'Rubric::EntryTag' => tag ]);
+__PACKAGE__->has_many(tags => [ 'Rubric::EntryTag' => 'tag' ]);
 
 =head3 recent_tags_counted
 
@@ -109,23 +115,23 @@ __PACKAGE__->has_a(
 	inflate => sub { gmtime($_[0]) }
 ) for qw(created modified);
 
-__PACKAGE__->add_trigger(before_create => \&default_title);
+__PACKAGE__->add_trigger(before_create => \&_default_title);
 
-__PACKAGE__->add_trigger(before_create => \&create_times);
-__PACKAGE__->add_trigger(before_update => \&update_times);
+__PACKAGE__->add_trigger(before_create => \&_create_times);
+__PACKAGE__->add_trigger(before_update => \&_update_times);
 
-sub default_title {
+sub _default_title {
 	my $self = shift;
 	$self->title('(default)') unless $self->{title}
 }
 
-sub create_times {
+sub _create_times {
 	my $self = shift;
-	$self->created(scalar gmtime) unless $self->{created};
-	$self->modified(scalar gmtime) unless $self->{modified};
+	$self->created(scalar gmtime) unless defined $self->{created};
+	$self->modified(scalar gmtime) unless defined $self->{modified};
 }
 
-sub update_times {
+sub _update_times {
 	my $self = shift;
 	$self->modified(scalar gmtime);
 }
