@@ -6,13 +6,13 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.03_03
+version 0.07_01
 
- $Id: WebApp.pm,v 1.76 2005/01/20 15:09:06 rjbs Exp $
+ $Id: WebApp.pm,v 1.85 2005/03/17 03:32:39 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.03_04';
+our $VERSION = '0.07_01';
 
 =head1 SYNOPSIS
 
@@ -46,9 +46,8 @@ basic dispatch table looks something like this:
  /post        | post or edit an entry (must be logged in) | post
  /edit        | edit an entry (must be logged in)         | edit
  /delete      | delete an entry (must be logged in)       | delete
- /user/NAME   | see a user's entries                      | user
- /user/N/TAGS | see a user's entries for given tags       | user
- /tag/TAGS    | see entries for given tags                | tag
+ /entries/Q   | find and display results for query Q      | entries
+ /~USER/TAGS  | see a user's entries for given tags       | (in flux)
  /doc/PAGE    | view the named page in the documentation  | doc
 
 If the system is private and no user is logged in, the default action is to
@@ -126,6 +125,12 @@ sub cgiapp_init {
 	$self->param(path => [ @path[ 2 .. $#path ] ]);
 }
 
+=head2 next_path_part
+
+This method shifts the next item off of the request path and returns it.
+
+=cut
+
 sub next_path_part {
 	my ($self) = @_;
 	my $username = shift @{$self->param('path')};
@@ -210,7 +215,22 @@ sub setup {
 		]);
 	}
 
-	$self->run_modes(AUTOLOAD => 'redirect_root');
+	$self->run_modes(AUTOLOAD => '_default_handler');
+}
+
+sub _default_handler {
+	my ($self, $runmode) = @_;
+	if (substr($runmode, 0, 1) eq '~') {
+		return $self->_entries_shortcut(substr($runmode, 1));
+	}
+	$self->redirect_root;
+}
+
+sub _entries_shortcut {
+	my ($self, $user) = @_;
+	my $path = $self->param('path');
+	unshift @$path, 'user', $user, 'tags';
+	$self->entries;
 }
 
 =head2 entries
@@ -363,6 +383,13 @@ sub preferences {
 	$self->update_user(\%prefs);
 }
 
+=head2 update_user(\%prefs)
+
+This method will update the current user object with the changes in C<%prefs>,
+which is passed by the C<preferences> method.
+
+=cut
+
 sub update_user {
 	my ($self, $prefs) = @_;
 	for ($self->param('current_user')) {
@@ -383,6 +410,15 @@ sub _get_prefs_form {
 	return %form;
 }
 
+=head2 validate_prefs(\%prefs)
+
+Given a set of preference updates from a form submission, this method validates
+them and returns a description of the validation results.  This method will
+probably be redesigned (possibly with Data::FormValidator) in the future.
+Don't count on its interface.
+
+=cut
+
 sub validate_prefs {
 	my ($self, $prefs) = @_;
 	my %errors;
@@ -445,6 +481,15 @@ sub newuser {
 	}
 }
 
+=head2 validate_newuser_form(\%newuser)
+
+Given a set of user data from a form submission, this method validates them and
+returns a description of the validation results.  This method will probably be
+redesigned (possibly with Data::FormValidator) in the future.  Don't count on
+its interface.
+
+=cut
+
 sub validate_newuser_form {
 	my ($self, $newuser) = @_;
 	my %errors;
@@ -475,6 +520,13 @@ sub validate_newuser_form {
 	return %errors;
 }
 
+=head2 create_newuser(\%newuser)
+
+This method creates a new user account from the given description.  It sends
+the user a validation email (if needed) and displays an account creation page.
+
+=cut
+
 sub create_newuser {
 	my ($self, %newuser) = @_;
 
@@ -495,6 +547,12 @@ sub create_newuser {
 	$self->template("account_created");
 }
 
+=head2 send_verification_email_to($user)
+
+This method sends a verification email to the given user.
+
+=cut
+
 sub send_verification_email_to {
 	my ($self, $user) = @_;
 
@@ -530,6 +588,13 @@ sub verify {
 		: $self->redirect_root("BAD USER NO VALIDATION");
 }
 
+=head2 get_verification_code
+
+This gets the next part of the path and puts it in the C<verification_code>
+parameter.
+
+=cut
+
 sub get_verification_code {
 	my ($self) = @_;
 
@@ -538,10 +603,11 @@ sub get_verification_code {
 	return $self;
 }
 
-sub user {
-	my ($self) = @_;
-	$self->get_user->get_tags->display_entries;
-}
+=head2 get_user
+
+This gets the next part of the path and puts it in the C<user> parameter.
+
+=cut
 
 sub get_user {
 	my ($self) = @_;
@@ -625,9 +691,9 @@ sub render_entries {
 		entries => $self->param('entries'),
 		pages   => $self->param('pages'),
 		%$options,
-		remove  => sub { [ grep { $_ ne $_[0] } @{$_[1]} ] },
-		long_form   => scalar $self->query->param('long_form'),
-		recent_tags => $self->param('recent_tags'),
+		remove       => sub { [ grep { $_ ne $_[0] } @{$_[1]} ] },
+		long_form    => scalar $self->query->param('long_form'),
+		recent_tags  => $self->param('recent_tags'),
 	});
 }
 
@@ -684,8 +750,12 @@ sub post {
 		(($self->query->param('submit') || '') eq 'save')
 		and	
 		$self->param('current_user')->quick_entry(\%entry);
+	
+	my $when_done = $self->query->param('when_done');
 
-	my $goto_uri = ($self->query->param('when_done') eq 'go_back')
+	return $self->template('close_window') if $when_done eq 'close';
+
+	my $goto_uri = ($when_done eq 'go_back')
 		? $entry{uri}
 		: Rubric::WebApp::URI->entries({ user => $self->param('current_user') });
 	
